body {
  padding-top: 0px !important;
}

#nd_search-results > li:not(.active) {
  display: none !important;
}

.navbar, .nd_sidebar {
  display: none !important;
}

.content, .nd_content {
  margin-left: 0px !important;
  margin-right: 0px !important;
}

.floatThead-table {
  position: inherit;
  top: 45px;
}

a:after {
  content: "" !important;
}
